@@ -9,11 +9,11 @@ Text::Editor::Easy::Program::Eval::Exec - Execution of macro panel instructions
 
 =head1 VERSION
 
-Version 0.48
+Version 0.49
 
 =cut
 
-our $VERSION = '0.48';
+our $VERSION = '0.49';
 
 use Text::Editor::Easy::Comm;
 use threads;    # Pour debug
@@ -26,7 +26,7 @@ sub exec_eval {
 
 # Ajout d'une instruction "return if anything_for_me;" entre chaque ligne pour ractivit maximum
 
-    $program =~ s/;\n/;return if ( anything_for_me() );\n/g;
+    #$program =~ s/;\n/;return if ( anything_for_me() );\n/g;
     print DBG "Dans exec_eval(", threads->tid, ") : \n$program\n\n";
 
     #print substr ( $program, 0, 150 ), "\n\n";
@@ -52,7 +52,7 @@ sub exec_eval {
         'package' => __PACKAGE__,
         'call_id' => $call_id,
     );
-    Text::Editor::Easy->whose_name('Eval')->on_top;
+    Text::Editor::Easy->whose_name('Eval')->at_top;
     Text::Editor::Easy->trace_print( $hash_dump, $message );
     #print STDERR $message;
 }
